"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GetExportContentEntriesUseCase = void 0;
var _convertTaskToExportRecord = require("../../utils/convertTaskToExportRecord");
var _constants = require("../../../tasks/constants");
var _exportPath = require("../../../tasks/utils/helpers/exportPath");
class GetExportContentEntriesUseCase {
  constructor(params) {
    this.getTask = params.getTask;
    this.urlSigner = params.urlSigner;
  }
  async execute(params) {
    const task = await this.getTask(params.id);
    if (task?.definitionId !== _constants.EXPORT_CONTENT_ENTRIES_CONTROLLER_TASK) {
      return null;
    }
    const record = (0, _convertTaskToExportRecord.convertTaskToCmsExportRecord)(task);
    if (!record.files) {
      return record;
    }
    const files = await Promise.all(record.files.map(async file => {
      const key = (0, _exportPath.prependExportPath)(file.key);
      const {
        url: get
      } = await this.urlSigner.get({
        ...file,
        key
      });
      const {
        url: head
      } = await this.urlSigner.head({
        ...file,
        key
      });
      return {
        ...file,
        get,
        head
      };
    }));
    return {
      ...record,
      files
    };
  }
}
exports.GetExportContentEntriesUseCase = GetExportContentEntriesUseCase;

//# sourceMappingURL=GetExportContentEntriesUseCase.js.map