"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createDownloadFileFromUrl = exports.DownloadFileFromUrl = void 0;
var _sizeSegments = require("../../utils/helpers/sizeSegments");
class DownloadFileFromUrl {
  constructor(params) {
    this.file = params.file;
    this.fetch = params.fetch;
    this.nextRange = params.nextRange || 0;
    this.upload = params.upload;
    this.ranges = (0, _sizeSegments.createSizeSegments)(this.file.size, "10MB");
  }
  async process(onIteration) {
    let iteration = 0;
    while (true) {
      const next = this.ranges[this.nextRange];
      if (this.isDone() || !next) {
        await this.upload.complete();
        return "done";
      }
      let status = undefined;
      await onIteration({
        iteration,
        next: this.nextRange,
        segment: next,
        stop: input => {
          status = input;
        }
      });
      if (status === "done") {
        await this.upload.complete();
        return status;
      } else if (status === "aborted") {
        await this.upload.abort();
        return status;
      } else if (status === "continue") {
        return status;
      }
      iteration++;
      const headers = new Headers();
      if (this.ranges.length > 1) {
        headers.set("Range", `bytes=${next.start}-${next.end}`);
      }
      const result = await this.fetch(this.file.url, {
        method: "GET",
        keepalive: true,
        mode: "cors",
        headers
      });
      if (!result.ok) {
        throw new Error(`Failed to fetch URL: ${this.file.url}`);
      } else if (!result.body) {
        throw new Error(`Body not found for URL: ${this.file.url}`);
      }
      const buffer = await result.arrayBuffer();
      await this.upload.add(Buffer.from(buffer));
      this.nextRange++;
    }
  }
  async abort() {
    await this.upload.abort();
  }
  getNextRange() {
    return this.nextRange;
  }
  isDone() {
    return !this.ranges[this.nextRange];
  }
}
exports.DownloadFileFromUrl = DownloadFileFromUrl;
const createDownloadFileFromUrl = params => {
  return new DownloadFileFromUrl(params);
};
exports.createDownloadFileFromUrl = createDownloadFileFromUrl;

//# sourceMappingURL=DownloadFileFromUrl.js.map