"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getChildTasks = void 0;
var _tasks = require("@webiny/tasks");
const mapServiceStatusToTaskStatus = (task, serviceInfo) => {
  if (!serviceInfo) {
    console.log(`Service info is missing for task ${task.id} (${task.definitionId}).`);
    return null;
  }
  if (serviceInfo.status === "RUNNING") {
    return _tasks.TaskDataStatus.RUNNING;
  } else if (serviceInfo.status === "SUCCEEDED") {
    return _tasks.TaskDataStatus.SUCCESS;
  } else if (serviceInfo.status === "FAILED") {
    return _tasks.TaskDataStatus.FAILED;
  } else if (serviceInfo.status === "ABORTED") {
    return _tasks.TaskDataStatus.ABORTED;
  } else if (serviceInfo.status === "TIMED_OUT" || serviceInfo.status === "PENDING_REDRIVE") {
    console.log(`Service status is ${serviceInfo.status} for task ${task.id} (${task.definitionId}).`);
    return null;
  }
  return _tasks.TaskDataStatus.PENDING;
};
const getChildTasks = async ({
  context,
  task,
  definition
}) => {
  const running = [];
  const done = [];
  const invalid = [];
  const aborted = [];
  const failed = [];
  const collection = [];
  const {
    items
  } = await context.tasks.listTasks({
    where: {
      parentId: task.id,
      definitionId: definition
    },
    limit: 100000
  });
  for (const task of items) {
    collection.push(task);
    if (task.taskStatus === _tasks.TaskDataStatus.RUNNING || task.taskStatus === _tasks.TaskDataStatus.PENDING) {
      /**
       * We also need to check the actual status of the service.
       * It can happen that the task is marked as running, but the service is not running.
       */
      const serviceInfo = await context.tasks.fetchServiceInfo(task);
      const status = mapServiceStatusToTaskStatus(task, serviceInfo);
      if (status === null || !serviceInfo) {
        invalid.push(task.id);
        continue;
      } else if (status !== task.taskStatus) {
        console.error(`Status of the task is not same as the status of the service (task: ${task.taskStatus}, service: ${status} / ${serviceInfo.status}).`);
        invalid.push(task.id);
        continue;
      }
      running.push(task.id);
      continue;
    } else if (task.taskStatus === _tasks.TaskDataStatus.SUCCESS) {
      done.push(task.id);
      continue;
    } else if (task.taskStatus === _tasks.TaskDataStatus.FAILED) {
      failed.push(task.id);
      continue;
    } else if (task.taskStatus === _tasks.TaskDataStatus.ABORTED) {
      aborted.push(task.id);
      continue;
    }
    /**
     * Impossible to be in a state not listed above, but just in case.
     */
    invalid.push(task.id);
  }
  return {
    running,
    done,
    invalid,
    aborted,
    failed,
    collection
  };
};
exports.getChildTasks = getChildTasks;

//# sourceMappingURL=getChildTasks.js.map